==> aroundme_0_4_2.zip: aroundme_0_4_2/www/aroundme_0_4_2/sn_network.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

include "inc/header_sn.inc.php";


//ACS check
if (!$user_acs->checkPermission($c_acs['arr_acs']['resource']['social_network'], $c_acs['arr_acs']['privilege']['allow_access'])) { //resourece_id, Priv_id
	header("Location: " . $_SESSION['s_homepage'] . "?" . SID);
	exit;
}


//append language setup
require_once($languageArrayPath . 'arr_user.lang.php');


//setup file
$file->noimage = $c_node['file']['image']['thumb'][3]['noimage'];
$file->thumb = $c_node['file']['image']['thumb'][3]['name'];
$user->file = $file;


//setup social network
$sn->status_ids = $c_node['user']['status'];
$sn->date = $date;
$sn->user = $user;
$sn->relation_type_ids = $c_node['user']['relation_type'];


$output_friend_ids = $sn->getFriends($me['user_id']);
if (!empty($output_friend_ids)) {
	foreach($output_friend_ids as $key => $i):
		$user->user_ids[] = $i;
	endforeach;
}

$user->orderby = "p.profile_nic";
$output_friends = $user->getProfiles();
if (!empty($output_friends)) {
	foreach($output_friends as $key => $i):
		$total_friends = $sn->getFriends($i['user_id']);
		$output_friends[$key]['sn_total'] = count($total_friends);
	endforeach;
}


$output_network = $sn->getSocialNetworkSummary();
$network_relations = $sn->getPendingRelations();
if (!empty($network_relations)) {
    $output_outstanding_invites = count($network_relations[0]);
}
else {
    $output_outstanding_invites = 0;
}


//if they have no friends we redirect them to the form
if (empty($output_friends)) {
    return header("Location: sn_invite.php?" . SID);
	exit;
}


//MOVE TO TEMPLATE
if (!empty($output_friends)) {
	$body->set('friends', $output_friends);
}

if (!empty($output_outstanding_invites)) {
	$body->set('outstanding_invites', $output_outstanding_invites);
}

if (!empty($output_network)) {
	$body->set('network', $output_network);
}

$template_pageLink =  $lang['txt_network'];
$template_pageLinkNote = $lang['txt_profile'] . ": " . $output_profile['profile_nic'];

include "inc/footer.inc.php";

?>

==> aroundme_0_4_3.zip: aroundme_0_4_3/www/aroundme_0_4_3/sn_network.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

include "inc/header_sn.inc.php";


//ACS check
if (!$user_acs->checkPermission($c_acs['arr_acs']['resource']['social_network'], $c_acs['arr_acs']['privilege']['allow_access'])) { //resourece_id, Priv_id
	header("Location: " . $_SESSION['s_homepage'] . "?" . SID);
	exit;
}


//append language setup
require_once($languageArrayPath . 'arr_user.lang.php');


//setup file
$file->noimage = $c_node['file']['image']['thumb'][3]['noimage'];
$file->thumb = $c_node['file']['image']['thumb'][3]['name'];
$user->file = $file;


//setup social network
$sn->status_ids = $c_node['user']['status'];
$sn->date = $date;
$sn->user = $user;
$sn->relation_type_ids = $c_node['user']['relation_type'];


$output_friend_ids = $sn->getFriends($me['user_id']);
if (!empty($output_friend_ids)) {
	foreach($output_friend_ids as $key => $i):
		$user->user_ids[] = $i;
	endforeach;
}

$user->orderby = "p.profile_nic";
$output_friends = $user->getProfiles();
if (!empty($output_friends)) {
	foreach($output_friends as $key => $i):
		$total_friends = $sn->getFriends($i['user_id']);
		$output_friends[$key]['sn_total'] = count($total_friends);
	endforeach;
}


$output_network = $sn->getSocialNetworkSummary();
$network_relations = $sn->getPendingRelations();
if (!empty($network_relations)) {
    $output_outstanding_invites = count($network_relations);
}
else {
    $output_outstanding_invites = 0;
}

//if they have no friends we redirect them to the form
if (empty($output_friends)) {
    return header("Location: sn_invite.php?" . SID);
	exit;
}


//MOVE TO TEMPLATE
if (!empty($output_friends)) {
	$body->set('friends', $output_friends);
}

if (!empty($output_outstanding_invites)) {
	$body->set('outstanding_invites', $output_outstanding_invites);
}

if (!empty($output_network)) {
	$body->set('network', $output_network);
}

$template_pageLink =  $lang['txt_network'];
$template_pageLinkNote = $lang['txt_profile'] . ": " . $output_profile['profile_nic'];

include "inc/footer.inc.php";

?>
